@@ -1,4 +1,4 @@
-__version__ = "0.4.7"
+__version__ = "0.5.1"
 
 from .io import yaml_load, yaml_dump, save, load, json_load, json_dump
 from .path import *
@@ -9,7 +9,7 @@ from .nlp.parser import parse_to_obj, parse_to_code
 from .ai_platform.metrics import MetricsCalculator, save_pred_metrics
 from .llm.openaiclient import OpenAIClient
 from .vllm.client.image_processor_helper import ImageProcessor
-from .vllm.client.messages_processor import batch_messages_preprocess, batch_process_messages, messages_preprocess
+from .vllm.client.messages_processor import batch_messages_preprocess, batch_process_messages, messages_preprocess, ImageCacheConfig
 # from .decorators import benchmark
 # from .string.color_string import rgb_string
 # from .functions.core import clamp, topk, dict_topk
