@@ -374,6 +374,151 @@ Host {rsa_name}
   IdentitiesOnly yes
 """)
 
+    @staticmethod
+    def video_dedup(video_path: str, method: str = "phash", threshold: float = None, step: int = 1, resize: int = 256, workers: int = 1, fps: float = None, out_dir: str = "out"):
+        """
+        Detect and save unique frames from a video.
+
+        Args:
+            video_path (str): Path to the input video file.
+            method (str): Method for comparing frames (default: "phash").
+            threshold (float): Similarity threshold (method-specific default if not provided).
+            step (int): Sample every Nth frame (default: 1).
+            resize (int): Resize frame width before processing (default: 256).
+            workers (int): Number of worker processes for hashing (default: 1).
+            fps (float): Target frames per second to sample (default: None).
+            out_dir (str): Base directory to save unique frames (default: "out").
+                           Frames will be saved in '{out_dir}/{video_filename}/'.
+        """
+        from sparrow.dedup.video import VideoFrameDeduplicator
+        import cv2  # Import OpenCV
+        from pathlib import Path  # Import Path
+        from sparrow.performance._measure_time import MeasureTime # For timing
+
+        mt = MeasureTime().start()
+
+        try:
+            dedup = VideoFrameDeduplicator(
+                method=method,
+                threshold=threshold,
+                step=step,
+                resize=resize,
+                workers=workers,
+                fps=fps
+            )
+        except ValueError as e:
+            print(f"Error initializing deduplicator: {e}")
+            return # Or raise the error
+
+        try:
+            count = dedup.process_and_save_unique_frames(video_path, out_dir)
+            mt.show_interval(f"Completed processing. Saved {count} frames.") # Use simplified message
+        except Exception as e:
+            # Error messages are printed inside the method, just log completion time if needed
+             print(f"Operation failed: {e}") # Optionally print error here as well
+             # mt.show_interval("Operation failed.")
+
+    @staticmethod
+    def frames_to_video(frames_dir: str, output_video: str = None, fps: float = 15.0, codec: str = 'mp4v', use_av: bool = False):
+        """
+        将一个目录中的帧图像合成为视频。
+        
+        Args:
+            frames_dir (str): 包含帧图像的目录路径。
+            output_video (str, optional): 输出视频的路径。如果为None，则默认为frames_dir旁边的同名mp4文件。
+            fps (float, optional): 输出视频的帧率。默认为15.0。
+            codec (str, optional): 视频编解码器。默认为'mp4v'，可选'avc1'等。
+            use_av (bool, optional): 是否使用PyAV库加速（如果可用）。默认为False。
+        """
+        from sparrow.dedup.video import VideoFrameDeduplicator
+        from pathlib import Path
+        from sparrow.performance._measure_time import MeasureTime
+
+        mt = MeasureTime().start()
+        dedup = VideoFrameDeduplicator()  # 使用默认参数，这里实际上不需要设置去重参数
+        
+        try:
+            output_path = dedup.frames_to_video(
+                frames_dir=frames_dir,
+                output_video=output_video,
+                fps=fps,
+                codec=codec,
+                use_av=use_av
+            )
+            mt.show_interval(f"完成视频合成: {output_path}")
+        except Exception as e:
+            print(f"操作失败: {e}")
+
+    @staticmethod
+    def dedup_and_create_video(video_path: str, method: str = "phash", threshold: float = None, 
+                              step: int = 1, resize: int = 256, workers: int = 1, fps: float = None, 
+                              out_dir: str = "out", output_video: str = None, video_fps: float = 15.0, 
+                              codec: str = 'mp4v', use_av: bool = False):
+        """
+        从视频中提取唯一帧并合成新视频。
+
+        Args:
+            video_path (str): 输入视频文件路径。
+            method (str): 比较帧的方法 (默认: "phash")。
+            threshold (float): 相似度阈值 (如果未提供，则使用方法特定的默认值)。
+            step (int): 每N帧采样一次 (默认: 1)。
+            resize (int): 处理前调整帧宽度 (默认: 256)。
+            workers (int): 哈希计算的工作进程数 (默认: 1)。
+            fps (float): 提取的目标采样帧率 (默认: None)。
+            out_dir (str): 保存唯一帧的基础目录 (默认: "out")。
+            output_video (str): 输出视频的路径 (默认: 在输入目录旁)。
+            video_fps (float): 输出视频的帧率 (默认: 15.0)。
+            codec (str): 视频编解码器 (默认: 'mp4v')。
+            use_av (bool): 合成时使用PyAV库加速 (默认: False)。
+        """
+        from sparrow.dedup.video import VideoFrameDeduplicator
+        from pathlib import Path
+        from sparrow.performance._measure_time import MeasureTime
+
+        mt = MeasureTime().start()
+
+        try:
+            dedup = VideoFrameDeduplicator(
+                method=method,
+                threshold=threshold,
+                step=step,
+                resize=resize,
+                workers=workers,
+                fps=fps
+            )
+        except ValueError as e:
+            print(f"初始化去重器时出错: {e}")
+            return
+        
+        try:
+            # 1. 提取帧
+            count = dedup.process_and_save_unique_frames(video_path, out_dir)
+            print(f"完成提取。保存了 {count} 帧。")
+            
+            # 确定帧目录路径
+            src_path = Path(video_path)
+            if src_path.exists() and src_path.is_file():
+                frames_dir = Path(out_dir) / src_path.stem
+            else:
+                frames_dir = Path(out_dir)
+                
+            # 2. 合成视频
+            output_path = dedup.frames_to_video(
+                frames_dir=frames_dir,
+                output_video=output_video,
+                fps=video_fps,
+                codec=codec,
+                use_av=use_av
+            )
+            mt.show_interval(f"完成流程。提取 {count} 帧并合成视频: {output_path}")
+        except Exception as e:
+            print(f"操作失败: {e}")
+
+
+
+
+
+
 
 def fire_commands():
     import fire
